Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(305)

Unified Diff: components/arc/net/arc_net_host_impl.h

Issue 2133503002: arc: Revamp the ArcBridgeService interface (Closed) Base URL: https://chromium.googlesource.com/a/chromium/src.git@master
Patch Set: More rebasing Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/arc/metrics/arc_metrics_service.cc ('k') | components/arc/net/arc_net_host_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/arc/net/arc_net_host_impl.h
diff --git a/components/arc/net/arc_net_host_impl.h b/components/arc/net/arc_net_host_impl.h
index 8aa52b75982e88623330d0ee50e01a1a09535309..a21a0b01c97f2f30e403bd3b70d1fa5d8372ad8c 100644
--- a/components/arc/net/arc_net_host_impl.h
+++ b/components/arc/net/arc_net_host_impl.h
@@ -17,6 +17,7 @@
#include "components/arc/arc_bridge_service.h"
#include "components/arc/arc_service.h"
#include "components/arc/common/net.mojom.h"
+#include "components/arc/instance_holder.h"
#include "mojo/public/cpp/bindings/binding.h"
namespace base {
@@ -31,7 +32,7 @@ class ArcBridgeService;
// Private implementation of ArcNetHost.
class ArcNetHostImpl : public ArcService,
- public ArcBridgeService::Observer,
+ public InstanceHolder<mojom::NetInstance>::Observer,
public chromeos::NetworkStateHandlerObserver,
public mojom::NetHost {
public:
@@ -77,8 +78,8 @@ class ArcNetHostImpl : public ArcService,
void DeviceListChanged() override;
void GetDefaultNetwork(const GetDefaultNetworkCallback& callback) override;
- // Overridden from ArcBridgeService::Observer:
- void OnNetInstanceReady() override;
+ // Overridden from ArcBridgeService::InterfaceObserver<mojom::NetInstance>:
+ void OnInstanceReady() override;
private:
void DefaultNetworkSuccessCallback(const std::string& service_path,
« no previous file with comments | « components/arc/metrics/arc_metrics_service.cc ('k') | components/arc/net/arc_net_host_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698